.. _maite-explanation:

Explanation
===========

Articles and posts about topics relevant -- directly or indirectly -- to MAITE.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   explanation/protocol_overview
   explanation/type_hints_for_API_design
